%global srcname libsass

Name:           python-%{srcname}
Version:        0.22.0
Release:        %mkrel 3
Summary:        Python bindings for libsass
Group:          Development/Python

License:        MIT
URL:            https://github.com/sass/libsass-python
Source0:        %{url}/archive/%{version}/%{srcname}-%{version}.tar.gz
# Patch for correct naming of manpages
Patch0:         python-libsass-man.patch
Patch1:         0001-Fix-sphinx-extlinks-warning.patch

BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-six
BuildRequires:  python3-pytest
BuildRequires:  python3-werkzeug
BuildRequires:  pkgconfig(libsass)
BuildRequires:  gcc-c++
# Needed for docs
BuildRequires:  python3-sphinx

%description
This package provides a simple Python extension module
sass which is binding Libsass (written in C/C++ by Hampton
Catlin and Aaron Leung).

%package -n python3-%{srcname}
Summary:        Python 3 bindings for libsass
Group:          Development/Python
%{?python_provide:%python_provide python3-%{srcname}}

Requires:       python3-six

%description -n python3-%{srcname}
This package provides a simple Python 3 extension module
sass which is binding Libsass (written in C/C++ by Hampton
Catlin and Aaron Leung).

%prep
%autosetup -n %{srcname}-python-%{version} -p1

%build
# Export SYSTEM_SASS environment variable to use the
# system library, not the bundled one
export SYSTEM_SASS="true"
%pyproject_wheel
pushd docs
# There are differences between Python's naming of arches and the
# %%{_arch} macro. We need to ask Python for the platform name
LIBPATH=$(python3 -c "import os.path, glob; print(os.path.basename(glob.glob('../build/lib*')[0]))")
export PYTHONPATH=../build/${LIBPATH}
make man    SPHINXBUILD=sphinx-build-3
popd

# lib.linux-x86_64-cpython-310
# lib.linux-x86_64-cpython-3.10
%install
# Same as above
export SYSTEM_SASS="true"
%pyproject_install
install -m 644 -D docs/_build/man/pysassc.1 %{buildroot}%{_mandir}/man1/pysassc.1

%check
export PYTHONPATH=%{buildroot}%{python3_sitearch}
py.test-3 sasstests.py

%files -n python3-%{srcname}
%license LICENSE
%doc README.rst
%{python3_sitearch}/__pycache__/*
%{python3_sitearch}/_sass*.so
%{python3_sitearch}/%{srcname}-%{version}.dist-info/
%{python3_sitearch}/sass.py
%{python3_sitearch}/pysassc.py
%{python3_sitearch}/sasstests.py
%{python3_sitearch}/sassutils/
%{_mandir}/man1/pysassc.1.*
%{_bindir}/pysassc


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 0.22.0-3.mga10
+ Revision: 2240165
- Mageia 10 Mass Rebuild

* Sun Mar 02 2025 wally <wally> 0.22.0-2.mga10
+ Revision: 2157237
- rebuild for python3.13

* Mon Jan 01 2024 daviddavid <daviddavid> 0.22.0-1.mga10
+ Revision: 2025325
- new version: 0.22.0
- rebuild for py3.12

* Fri Mar 03 2023 daviddavid <daviddavid> 0.21.0-4.mga9
+ Revision: 1946640
- add patch to fix build with Sphinx >= 6.0

* Sun Nov 06 2022 papoteur <papoteur> 0.21.0-3.mga9
+ Revision: 1903929
- fix path to module for building docs
  port to pyproject

* Sat Mar 19 2022 umeabot <umeabot> 0.21.0-2.mga9
+ Revision: 1799148
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 mrambo3501 <mrambo3501> 0.21.0-1.mga9
+ Revision: 1778354
- version 0.21.0
- rebuild for python-3.10

* Mon Mar 22 2021 daviddavid <daviddavid> 0.20.1-1.mga9
+ Revision: 1707567
- new version: 0.20.1

* Mon Mar 22 2021 daviddavid <daviddavid> 0.20.0-2.mga9
+ Revision: 1707509
- rebuild for python 3.9

* Thu Sep 10 2020 joequant <joequant> 0.20.0-1.mga8
+ Revision: 1624143
- imported package python-libsass

